==> huaweicloudsdkgaussdb-3.1.68-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/modify_proxy_weight_readonly_node.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ModifyProxyWeightReadonlyNode:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'id': 'str',
        'weight': 'int'
    }

    attribute_map = {
        'id': 'id',
        'weight': 'weight'
    }

    def __init__(self, id=None, weight=None):
        """ModifyProxyWeightReadonlyNode

        The model defined in huaweicloud sdk

        :param id: 只读节点ID
        :type id: str
        :param weight: 只读节点权重
        :type weight: int
        """
        
        

        self._id = None
        self._weight = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if weight is not None:
            self.weight = weight

    @property
    def id(self):
        """Gets the id of this ModifyProxyWeightReadonlyNode.

        只读节点ID

        :return: The id of this ModifyProxyWeightReadonlyNode.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ModifyProxyWeightReadonlyNode.

        只读节点ID

        :param id: The id of this ModifyProxyWeightReadonlyNode.
        :type id: str
        """
        self._id = id

    @property
    def weight(self):
        """Gets the weight of this ModifyProxyWeightReadonlyNode.

        只读节点权重

        :return: The weight of this ModifyProxyWeightReadonlyNode.
        :rtype: int
        """
        return self._weight

    @weight.setter
    def weight(self, weight):
        """Sets the weight of this ModifyProxyWeightReadonlyNode.

        只读节点权重

        :param weight: The weight of this ModifyProxyWeightReadonlyNode.
        :type weight: int
        """
        self._weight = weight

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModifyProxyWeightReadonlyNode):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgaussdb-3.1.158-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/modify_proxy_weight_readonly_node.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ModifyProxyWeightReadonlyNode:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'id': 'str',
        'weight': 'int'
    }

    attribute_map = {
        'id': 'id',
        'weight': 'weight'
    }

    def __init__(self, id=None, weight=None):
        r"""ModifyProxyWeightReadonlyNode

        The model defined in huaweicloud sdk

        :param id: 只读节点ID
        :type id: str
        :param weight: 只读节点权重
        :type weight: int
        """
        
        

        self._id = None
        self._weight = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if weight is not None:
            self.weight = weight

    @property
    def id(self):
        r"""Gets the id of this ModifyProxyWeightReadonlyNode.

        只读节点ID

        :return: The id of this ModifyProxyWeightReadonlyNode.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        r"""Sets the id of this ModifyProxyWeightReadonlyNode.

        只读节点ID

        :param id: The id of this ModifyProxyWeightReadonlyNode.
        :type id: str
        """
        self._id = id

    @property
    def weight(self):
        r"""Gets the weight of this ModifyProxyWeightReadonlyNode.

        只读节点权重

        :return: The weight of this ModifyProxyWeightReadonlyNode.
        :rtype: int
        """
        return self._weight

    @weight.setter
    def weight(self, weight):
        r"""Sets the weight of this ModifyProxyWeightReadonlyNode.

        只读节点权重

        :param weight: The weight of this ModifyProxyWeightReadonlyNode.
        :type weight: int
        """
        self._weight = weight

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModifyProxyWeightReadonlyNode):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
